# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Iterable, cast

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ....pagination import SyncV4PagePaginationArray, AsyncV4PagePaginationArray
from ...._base_client import AsyncPaginator, make_request_options
from ....types.zero_trust.devices import (
    deployment_group_edit_params,
    deployment_group_list_params,
    deployment_group_create_params,
)
from ....types.zero_trust.devices.deployment_group import DeploymentGroup
from ....types.zero_trust.devices.deployment_group_delete_response import DeploymentGroupDeleteResponse

__all__ = ["DeploymentGroupsResource", "AsyncDeploymentGroupsResource"]


class DeploymentGroupsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DeploymentGroupsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return DeploymentGroupsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DeploymentGroupsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return DeploymentGroupsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        name: str,
        version_config: Iterable[deployment_group_create_params.VersionConfig],
        policy_ids: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentGroup:
        """Creates a new deployment group.

        Policy IDs must be unique across all deployment
        groups. This endpoint is in Beta.

        Args:
          name: A user-friendly name for the deployment group.

          version_config: Contains at least one version configuration.

          policy_ids: Contains an optional list of policy IDs assigned to a group.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/devices/deployment-groups", account_id=account_id),
            body=maybe_transform(
                {
                    "name": name,
                    "version_config": version_config,
                    "policy_ids": policy_ids,
                },
                deployment_group_create_params.DeploymentGroupCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[DeploymentGroup]._unwrapper,
            ),
            cast_to=cast(Type[DeploymentGroup], ResultWrapper[DeploymentGroup]),
        )

    def list(
        self,
        *,
        account_id: str,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncV4PagePaginationArray[DeploymentGroup]:
        """Lists all deployment groups for an account.

        Use deployment groups to assign
        target WARP client versions to specific devices. This endpoint is in Beta.

        Args:
          page: The page number to return.

          per_page: The maximum number of deployment groups to return per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/devices/deployment-groups", account_id=account_id),
            page=SyncV4PagePaginationArray[DeploymentGroup],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "per_page": per_page,
                    },
                    deployment_group_list_params.DeploymentGroupListParams,
                ),
            ),
            model=DeploymentGroup,
        )

    def delete(
        self,
        group_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentGroupDeleteResponse:
        """Deletes a deployment group.

        Associated policies no longer apply and devices stop
        receiving version targets. This endpoint is in Beta.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        return self._delete(
            path_template(
                "/accounts/{account_id}/devices/deployment-groups/{group_id}", account_id=account_id, group_id=group_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[DeploymentGroupDeleteResponse]._unwrapper,
            ),
            cast_to=cast(Type[DeploymentGroupDeleteResponse], ResultWrapper[DeploymentGroupDeleteResponse]),
        )

    def edit(
        self,
        group_id: str,
        *,
        account_id: str,
        name: str | Omit = omit,
        policy_ids: SequenceNotStr[str] | Omit = omit,
        version_config: Iterable[deployment_group_edit_params.VersionConfig] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentGroup:
        """Updates a deployment group.

        Returns 409 if any newly added policy IDs already
        belong to another deployment group. This endpoint is in Beta.

        Args:
          name: A user-friendly name for the deployment group.

          policy_ids: Replaces the entire list of policy IDs.

          version_config: Replaces the entire version_config array.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        return self._patch(
            path_template(
                "/accounts/{account_id}/devices/deployment-groups/{group_id}", account_id=account_id, group_id=group_id
            ),
            body=maybe_transform(
                {
                    "name": name,
                    "policy_ids": policy_ids,
                    "version_config": version_config,
                },
                deployment_group_edit_params.DeploymentGroupEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[DeploymentGroup]._unwrapper,
            ),
            cast_to=cast(Type[DeploymentGroup], ResultWrapper[DeploymentGroup]),
        )

    def get(
        self,
        group_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentGroup:
        """Fetches a single deployment group by its ID.

        This endpoint is in Beta.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/devices/deployment-groups/{group_id}", account_id=account_id, group_id=group_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[DeploymentGroup]._unwrapper,
            ),
            cast_to=cast(Type[DeploymentGroup], ResultWrapper[DeploymentGroup]),
        )


class AsyncDeploymentGroupsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDeploymentGroupsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncDeploymentGroupsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDeploymentGroupsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncDeploymentGroupsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        name: str,
        version_config: Iterable[deployment_group_create_params.VersionConfig],
        policy_ids: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentGroup:
        """Creates a new deployment group.

        Policy IDs must be unique across all deployment
        groups. This endpoint is in Beta.

        Args:
          name: A user-friendly name for the deployment group.

          version_config: Contains at least one version configuration.

          policy_ids: Contains an optional list of policy IDs assigned to a group.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/devices/deployment-groups", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "name": name,
                    "version_config": version_config,
                    "policy_ids": policy_ids,
                },
                deployment_group_create_params.DeploymentGroupCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[DeploymentGroup]._unwrapper,
            ),
            cast_to=cast(Type[DeploymentGroup], ResultWrapper[DeploymentGroup]),
        )

    def list(
        self,
        *,
        account_id: str,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[DeploymentGroup, AsyncV4PagePaginationArray[DeploymentGroup]]:
        """Lists all deployment groups for an account.

        Use deployment groups to assign
        target WARP client versions to specific devices. This endpoint is in Beta.

        Args:
          page: The page number to return.

          per_page: The maximum number of deployment groups to return per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/devices/deployment-groups", account_id=account_id),
            page=AsyncV4PagePaginationArray[DeploymentGroup],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "per_page": per_page,
                    },
                    deployment_group_list_params.DeploymentGroupListParams,
                ),
            ),
            model=DeploymentGroup,
        )

    async def delete(
        self,
        group_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentGroupDeleteResponse:
        """Deletes a deployment group.

        Associated policies no longer apply and devices stop
        receiving version targets. This endpoint is in Beta.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        return await self._delete(
            path_template(
                "/accounts/{account_id}/devices/deployment-groups/{group_id}", account_id=account_id, group_id=group_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[DeploymentGroupDeleteResponse]._unwrapper,
            ),
            cast_to=cast(Type[DeploymentGroupDeleteResponse], ResultWrapper[DeploymentGroupDeleteResponse]),
        )

    async def edit(
        self,
        group_id: str,
        *,
        account_id: str,
        name: str | Omit = omit,
        policy_ids: SequenceNotStr[str] | Omit = omit,
        version_config: Iterable[deployment_group_edit_params.VersionConfig] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentGroup:
        """Updates a deployment group.

        Returns 409 if any newly added policy IDs already
        belong to another deployment group. This endpoint is in Beta.

        Args:
          name: A user-friendly name for the deployment group.

          policy_ids: Replaces the entire list of policy IDs.

          version_config: Replaces the entire version_config array.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        return await self._patch(
            path_template(
                "/accounts/{account_id}/devices/deployment-groups/{group_id}", account_id=account_id, group_id=group_id
            ),
            body=await async_maybe_transform(
                {
                    "name": name,
                    "policy_ids": policy_ids,
                    "version_config": version_config,
                },
                deployment_group_edit_params.DeploymentGroupEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[DeploymentGroup]._unwrapper,
            ),
            cast_to=cast(Type[DeploymentGroup], ResultWrapper[DeploymentGroup]),
        )

    async def get(
        self,
        group_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentGroup:
        """Fetches a single deployment group by its ID.

        This endpoint is in Beta.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/devices/deployment-groups/{group_id}", account_id=account_id, group_id=group_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[DeploymentGroup]._unwrapper,
            ),
            cast_to=cast(Type[DeploymentGroup], ResultWrapper[DeploymentGroup]),
        )


class DeploymentGroupsResourceWithRawResponse:
    def __init__(self, deployment_groups: DeploymentGroupsResource) -> None:
        self._deployment_groups = deployment_groups

        self.create = to_raw_response_wrapper(
            deployment_groups.create,
        )
        self.list = to_raw_response_wrapper(
            deployment_groups.list,
        )
        self.delete = to_raw_response_wrapper(
            deployment_groups.delete,
        )
        self.edit = to_raw_response_wrapper(
            deployment_groups.edit,
        )
        self.get = to_raw_response_wrapper(
            deployment_groups.get,
        )


class AsyncDeploymentGroupsResourceWithRawResponse:
    def __init__(self, deployment_groups: AsyncDeploymentGroupsResource) -> None:
        self._deployment_groups = deployment_groups

        self.create = async_to_raw_response_wrapper(
            deployment_groups.create,
        )
        self.list = async_to_raw_response_wrapper(
            deployment_groups.list,
        )
        self.delete = async_to_raw_response_wrapper(
            deployment_groups.delete,
        )
        self.edit = async_to_raw_response_wrapper(
            deployment_groups.edit,
        )
        self.get = async_to_raw_response_wrapper(
            deployment_groups.get,
        )


class DeploymentGroupsResourceWithStreamingResponse:
    def __init__(self, deployment_groups: DeploymentGroupsResource) -> None:
        self._deployment_groups = deployment_groups

        self.create = to_streamed_response_wrapper(
            deployment_groups.create,
        )
        self.list = to_streamed_response_wrapper(
            deployment_groups.list,
        )
        self.delete = to_streamed_response_wrapper(
            deployment_groups.delete,
        )
        self.edit = to_streamed_response_wrapper(
            deployment_groups.edit,
        )
        self.get = to_streamed_response_wrapper(
            deployment_groups.get,
        )


class AsyncDeploymentGroupsResourceWithStreamingResponse:
    def __init__(self, deployment_groups: AsyncDeploymentGroupsResource) -> None:
        self._deployment_groups = deployment_groups

        self.create = async_to_streamed_response_wrapper(
            deployment_groups.create,
        )
        self.list = async_to_streamed_response_wrapper(
            deployment_groups.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            deployment_groups.delete,
        )
        self.edit = async_to_streamed_response_wrapper(
            deployment_groups.edit,
        )
        self.get = async_to_streamed_response_wrapper(
            deployment_groups.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.network_interconnects import slot_list_params
from ...types.network_interconnects.slot_get_response import SlotGetResponse
from ...types.network_interconnects.slot_list_response import SlotListResponse

__all__ = ["SlotsResource", "AsyncSlotsResource"]


class SlotsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SlotsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return SlotsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SlotsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return SlotsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        account_id: str,
        address_contains: Optional[str] | Omit = omit,
        cursor: Optional[int] | Omit = omit,
        limit: Optional[int] | Omit = omit,
        occupied: Optional[bool] | Omit = omit,
        site: Optional[str] | Omit = omit,
        speed: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SlotListResponse:
        """
        Retrieve a list of all slots matching the specified parameters

        Args:
          account_id: Customer account tag

          address_contains: If specified, only show slots with the given text in their address field

          occupied: If specified, only show slots with a specific occupied/unoccupied state

          site: If specified, only show slots located at the given site

          speed: If specified, only show slots that support the given speed

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get(
            path_template("/accounts/{account_id}/cni/slots", account_id=account_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "address_contains": address_contains,
                        "cursor": cursor,
                        "limit": limit,
                        "occupied": occupied,
                        "site": site,
                        "speed": speed,
                    },
                    slot_list_params.SlotListParams,
                ),
            ),
            cast_to=SlotListResponse,
        )

    def get(
        self,
        slot: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SlotGetResponse:
        """
        Get information about the specified slot

        Args:
          account_id: Customer account tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not slot:
            raise ValueError(f"Expected a non-empty value for `slot` but received {slot!r}")
        return self._get(
            path_template("/accounts/{account_id}/cni/slots/{slot}", account_id=account_id, slot=slot),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SlotGetResponse,
        )


class AsyncSlotsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSlotsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSlotsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSlotsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncSlotsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        account_id: str,
        address_contains: Optional[str] | Omit = omit,
        cursor: Optional[int] | Omit = omit,
        limit: Optional[int] | Omit = omit,
        occupied: Optional[bool] | Omit = omit,
        site: Optional[str] | Omit = omit,
        speed: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SlotListResponse:
        """
        Retrieve a list of all slots matching the specified parameters

        Args:
          account_id: Customer account tag

          address_contains: If specified, only show slots with the given text in their address field

          occupied: If specified, only show slots with a specific occupied/unoccupied state

          site: If specified, only show slots located at the given site

          speed: If specified, only show slots that support the given speed

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._get(
            path_template("/accounts/{account_id}/cni/slots", account_id=account_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "address_contains": address_contains,
                        "cursor": cursor,
                        "limit": limit,
                        "occupied": occupied,
                        "site": site,
                        "speed": speed,
                    },
                    slot_list_params.SlotListParams,
                ),
            ),
            cast_to=SlotListResponse,
        )

    async def get(
        self,
        slot: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SlotGetResponse:
        """
        Get information about the specified slot

        Args:
          account_id: Customer account tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not slot:
            raise ValueError(f"Expected a non-empty value for `slot` but received {slot!r}")
        return await self._get(
            path_template("/accounts/{account_id}/cni/slots/{slot}", account_id=account_id, slot=slot),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SlotGetResponse,
        )


class SlotsResourceWithRawResponse:
    def __init__(self, slots: SlotsResource) -> None:
        self._slots = slots

        self.list = to_raw_response_wrapper(
            slots.list,
        )
        self.get = to_raw_response_wrapper(
            slots.get,
        )


class AsyncSlotsResourceWithRawResponse:
    def __init__(self, slots: AsyncSlotsResource) -> None:
        self._slots = slots

        self.list = async_to_raw_response_wrapper(
            slots.list,
        )
        self.get = async_to_raw_response_wrapper(
            slots.get,
        )


class SlotsResourceWithStreamingResponse:
    def __init__(self, slots: SlotsResource) -> None:
        self._slots = slots

        self.list = to_streamed_response_wrapper(
            slots.list,
        )
        self.get = to_streamed_response_wrapper(
            slots.get,
        )


class AsyncSlotsResourceWithStreamingResponse:
    def __init__(self, slots: AsyncSlotsResource) -> None:
        self._slots = slots

        self.list = async_to_streamed_response_wrapper(
            slots.list,
        )
        self.get = async_to_streamed_response_wrapper(
            slots.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Required, TypedDict

from ....._types import SequenceNotStr
from ..split_tunnel_exclude_param import SplitTunnelExcludeParam
from ..split_tunnel_include_param import SplitTunnelIncludeParam

__all__ = ["CustomEditParams", "ServiceModeV2", "VirtualNetworks"]


class CustomEditParams(TypedDict, total=False):
    account_id: Required[str]

    allow_mode_switch: bool
    """Whether to allow the user to switch WARP between modes."""

    allow_updates: bool
    """
    Whether to receive update notifications when a new version of the client is
    available.
    """

    allowed_to_leave: bool
    """Whether to allow devices to leave the organization."""

    auto_connect: float
    """The amount of time in seconds to reconnect after having been disabled."""

    captive_portal: float
    """Turn on the captive portal after the specified amount of time."""

    description: str
    """A description of the policy."""

    disable_auto_fallback: bool
    """
    If the `dns_server` field of a fallback domain is not present, the client will
    fall back to a best guess of the default/system DNS resolvers unless this policy
    option is set to `true`.
    """

    enabled: bool
    """Whether the policy will be applied to matching devices."""

    exclude: Iterable[SplitTunnelExcludeParam]
    """List of routes excluded in the WARP client's tunnel.

    Both 'exclude' and 'include' cannot be set in the same request.
    """

    exclude_office_ips: bool
    """Whether to add Microsoft IPs to Split Tunnel exclusions."""

    include: Iterable[SplitTunnelIncludeParam]
    """List of routes included in the WARP client's tunnel.

    Both 'exclude' and 'include' cannot be set in the same request.
    """

    lan_allow_minutes: float
    """The amount of time in minutes a user is allowed access to their LAN.

    A value of 0 will allow LAN access until the next WARP reconnection, such as a
    reboot or a laptop waking from sleep. Note that this field is omitted from the
    response if null or unset.
    """

    lan_allow_subnet_size: float
    """The size of the subnet for the local access network.

    Note that this field is omitted from the response if null or unset.
    """

    match: str
    """The wirefilter expression to match devices.

    Available values: "identity.email", "identity.groups.id",
    "identity.groups.name", "identity.groups.email", "identity.service_token_uuid",
    "identity.saml_attributes", "network", "os.name", "os.version".
    """

    name: str
    """The name of the device settings profile."""

    precedence: float
    """The precedence of the policy.

    Lower values indicate higher precedence. Policies will be evaluated in ascending
    order of this field.
    """

    register_interface_ip_with_dns: bool
    """
    Determines if the operating system will register WARP's local interface IP with
    your on-premises DNS server.
    """

    sccm_vpn_boundary_support: bool
    """
    Determines whether the WARP client indicates to SCCM that it is inside a VPN
    boundary. (Windows only).
    """

    service_mode_v2: ServiceModeV2

    support_url: str
    """The URL to launch when the Send Feedback button is clicked."""

    switch_locked: bool
    """
    Whether to allow the user to turn off the WARP switch and disconnect the client.
    """

    tunnel_protocol: str
    """Determines which tunnel protocol to use."""

    virtual_networks: Optional[VirtualNetworks]
    """Virtual network access settings for the device."""


class ServiceModeV2(TypedDict, total=False):
    mode: str
    """The mode to run the WARP client under."""

    port: float
    """The port number when used with proxy mode."""


class VirtualNetworks(TypedDict, total=False):
    """Virtual network access settings for the device."""

    allowed: Required[SequenceNotStr[str]]
    """List of virtual network IDs the device is allowed to access.

    When virtual_networks is set, at least one entry is required.
    """

    default: Required[str]
    """The default virtual network ID. Must be included in the `allowed` list."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.brand_protection.v2 import query_get_params
from ....types.brand_protection.v2.query_get_response import QueryGetResponse

__all__ = ["QueriesResource", "AsyncQueriesResource"]


class QueriesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> QueriesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return QueriesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> QueriesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return QueriesResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        account_id: str,
        id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> QueryGetResponse:
        """
        Get all saved brand protection queries for an account

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/cloudforce-one/v2/brand-protection/domain/queries", account_id=account_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"id": id}, query_get_params.QueryGetParams),
            ),
            cast_to=QueryGetResponse,
        )


class AsyncQueriesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncQueriesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncQueriesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncQueriesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncQueriesResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        account_id: str,
        id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> QueryGetResponse:
        """
        Get all saved brand protection queries for an account

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/cloudforce-one/v2/brand-protection/domain/queries", account_id=account_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"id": id}, query_get_params.QueryGetParams),
            ),
            cast_to=QueryGetResponse,
        )


class QueriesResourceWithRawResponse:
    def __init__(self, queries: QueriesResource) -> None:
        self._queries = queries

        self.get = to_raw_response_wrapper(
            queries.get,
        )


class AsyncQueriesResourceWithRawResponse:
    def __init__(self, queries: AsyncQueriesResource) -> None:
        self._queries = queries

        self.get = async_to_raw_response_wrapper(
            queries.get,
        )


class QueriesResourceWithStreamingResponse:
    def __init__(self, queries: QueriesResource) -> None:
        self._queries = queries

        self.get = to_streamed_response_wrapper(
            queries.get,
        )


class AsyncQueriesResourceWithStreamingResponse:
    def __init__(self, queries: AsyncQueriesResource) -> None:
        self._queries = queries

        self.get = async_to_streamed_response_wrapper(
            queries.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Literal, Annotated, TypeAlias

from pydantic import Field as FieldInfo

from ..._utils import PropertyInfo
from ..._models import BaseModel

__all__ = [
    "OnRampUpdateResponse",
    "PlannedMonthlyCostEstimate",
    "PlannedResource",
    "PlannedResourceDiff",
    "PlannedResourceMonthlyCostEstimateDiff",
    "PlannedResourceResource",
    "PostApplyMonthlyCostEstimate",
    "PostApplyResources",
    "PostApplyResourcesMonthlyCostEstimate",
    "PostApplyResourcesObservations",
    "PostApplyResourcesSection",
    "PostApplyResourcesSectionHiddenItem",
    "PostApplyResourcesSectionHiddenItemValue",
    "PostApplyResourcesSectionHiddenItemValueMcnStringItem",
    "PostApplyResourcesSectionHiddenItemValueMcnYamlItem",
    "PostApplyResourcesSectionHiddenItemValueMcnYamlDiffItem",
    "PostApplyResourcesSectionHiddenItemValueMcnYamlDiffItemYamlDiff",
    "PostApplyResourcesSectionHiddenItemValueMcnResourcePreviewItem",
    "PostApplyResourcesSectionHiddenItemValueMcnResourcePreviewItemResourcePreview",
    "PostApplyResourcesSectionHiddenItemValueMcnListItem",
    "PostApplyResourcesSectionHiddenItemValueMcnListItemList",
    "PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnStringItem",
    "PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnResourcePreviewItem",
    "PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnResourcePreviewItemResourcePreview",
    "PostApplyResourcesSectionVisibleItem",
    "PostApplyResourcesSectionVisibleItemValue",
    "PostApplyResourcesSectionVisibleItemValueMcnStringItem",
    "PostApplyResourcesSectionVisibleItemValueMcnYamlItem",
    "PostApplyResourcesSectionVisibleItemValueMcnYamlDiffItem",
    "PostApplyResourcesSectionVisibleItemValueMcnYamlDiffItemYamlDiff",
    "PostApplyResourcesSectionVisibleItemValueMcnResourcePreviewItem",
    "PostApplyResourcesSectionVisibleItemValueMcnResourcePreviewItemResourcePreview",
    "PostApplyResourcesSectionVisibleItemValueMcnListItem",
    "PostApplyResourcesSectionVisibleItemValueMcnListItemList",
    "PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnStringItem",
    "PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnResourcePreviewItem",
    "PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnResourcePreviewItemResourcePreview",
    "PostApplyResourcesManagedBy",
    "Status",
    "StatusApplyProgress",
    "StatusPlanProgress",
    "StatusLifecycleErrors",
    "StatusLifecycleErrorsMeta",
    "StatusLifecycleErrorsSource",
    "VPCsByID",
    "VPCsByIDMonthlyCostEstimate",
    "VPCsByIDObservations",
    "VPCsByIDSection",
    "VPCsByIDSectionHiddenItem",
    "VPCsByIDSectionHiddenItemValue",
    "VPCsByIDSectionHiddenItemValueMcnStringItem",
    "VPCsByIDSectionHiddenItemValueMcnYamlItem",
    "VPCsByIDSectionHiddenItemValueMcnYamlDiffItem",
    "VPCsByIDSectionHiddenItemValueMcnYamlDiffItemYamlDiff",
    "VPCsByIDSectionHiddenItemValueMcnResourcePreviewItem",
    "VPCsByIDSectionHiddenItemValueMcnResourcePreviewItemResourcePreview",
    "VPCsByIDSectionHiddenItemValueMcnListItem",
    "VPCsByIDSectionHiddenItemValueMcnListItemList",
    "VPCsByIDSectionHiddenItemValueMcnListItemListMcnStringItem",
    "VPCsByIDSectionHiddenItemValueMcnListItemListMcnResourcePreviewItem",
    "VPCsByIDSectionHiddenItemValueMcnListItemListMcnResourcePreviewItemResourcePreview",
    "VPCsByIDSectionVisibleItem",
    "VPCsByIDSectionVisibleItemValue",
    "VPCsByIDSectionVisibleItemValueMcnStringItem",
    "VPCsByIDSectionVisibleItemValueMcnYamlItem",
    "VPCsByIDSectionVisibleItemValueMcnYamlDiffItem",
    "VPCsByIDSectionVisibleItemValueMcnYamlDiffItemYamlDiff",
    "VPCsByIDSectionVisibleItemValueMcnResourcePreviewItem",
    "VPCsByIDSectionVisibleItemValueMcnResourcePreviewItemResourcePreview",
    "VPCsByIDSectionVisibleItemValueMcnListItem",
    "VPCsByIDSectionVisibleItemValueMcnListItemList",
    "VPCsByIDSectionVisibleItemValueMcnListItemListMcnStringItem",
    "VPCsByIDSectionVisibleItemValueMcnListItemListMcnResourcePreviewItem",
    "VPCsByIDSectionVisibleItemValueMcnListItemListMcnResourcePreviewItemResourcePreview",
    "VPCsByIDManagedBy",
]


class PlannedMonthlyCostEstimate(BaseModel):
    currency: str

    current_monthly_cost: float

    diff: float

    proposed_monthly_cost: float


class PlannedResourceDiff(BaseModel):
    diff: str

    left_description: str

    left_yaml: str

    right_description: str

    right_yaml: str


class PlannedResourceMonthlyCostEstimateDiff(BaseModel):
    currency: str

    current_monthly_cost: float

    diff: float

    proposed_monthly_cost: float


class PlannedResourceResource(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class PlannedResource(BaseModel):
    diff: PlannedResourceDiff

    keys_require_replace: List[str]

    monthly_cost_estimate_diff: PlannedResourceMonthlyCostEstimateDiff

    planned_action: Literal["no_op", "create", "update", "replace", "destroy"]

    resource: PlannedResourceResource


class PostApplyMonthlyCostEstimate(BaseModel):
    currency: str

    monthly_cost: float


class PostApplyResourcesMonthlyCostEstimate(BaseModel):
    currency: str

    monthly_cost: float


class PostApplyResourcesObservations(BaseModel):
    first_observed_at: str

    last_observed_at: str

    provider_id: str

    resource_id: str


class PostApplyResourcesSectionHiddenItemValueMcnStringItem(BaseModel):
    item_type: str

    string: str


class PostApplyResourcesSectionHiddenItemValueMcnYamlItem(BaseModel):
    item_type: str

    yaml: str


class PostApplyResourcesSectionHiddenItemValueMcnYamlDiffItemYamlDiff(BaseModel):
    diff: str

    left_description: str

    left_yaml: str

    right_description: str

    right_yaml: str


class PostApplyResourcesSectionHiddenItemValueMcnYamlDiffItem(BaseModel):
    item_type: str

    yaml_diff: PostApplyResourcesSectionHiddenItemValueMcnYamlDiffItemYamlDiff


class PostApplyResourcesSectionHiddenItemValueMcnResourcePreviewItemResourcePreview(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class PostApplyResourcesSectionHiddenItemValueMcnResourcePreviewItem(BaseModel):
    item_type: str

    resource_preview: PostApplyResourcesSectionHiddenItemValueMcnResourcePreviewItemResourcePreview


class PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnStringItem(BaseModel):
    item_type: str

    string: str


class PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnResourcePreviewItemResourcePreview(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnResourcePreviewItem(BaseModel):
    item_type: str

    resource_preview: PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnResourcePreviewItemResourcePreview


PostApplyResourcesSectionHiddenItemValueMcnListItemList: TypeAlias = Annotated[
    Union[
        PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnStringItem,
        PostApplyResourcesSectionHiddenItemValueMcnListItemListMcnResourcePreviewItem,
    ],
    PropertyInfo(discriminator="item_type"),
]


class PostApplyResourcesSectionHiddenItemValueMcnListItem(BaseModel):
    item_type: str

    rule_list: List[PostApplyResourcesSectionHiddenItemValueMcnListItemList] = FieldInfo(alias="list")


PostApplyResourcesSectionHiddenItemValue: TypeAlias = Annotated[
    Union[
        PostApplyResourcesSectionHiddenItemValueMcnStringItem,
        PostApplyResourcesSectionHiddenItemValueMcnYamlItem,
        PostApplyResourcesSectionHiddenItemValueMcnYamlDiffItem,
        PostApplyResourcesSectionHiddenItemValueMcnResourcePreviewItem,
        PostApplyResourcesSectionHiddenItemValueMcnListItem,
    ],
    PropertyInfo(discriminator="item_type"),
]


class PostApplyResourcesSectionHiddenItem(BaseModel):
    help_text: Optional[str] = FieldInfo(alias="helpText", default=None)

    name: Optional[str] = None

    value: Optional[PostApplyResourcesSectionHiddenItemValue] = None


class PostApplyResourcesSectionVisibleItemValueMcnStringItem(BaseModel):
    item_type: str

    string: str


class PostApplyResourcesSectionVisibleItemValueMcnYamlItem(BaseModel):
    item_type: str

    yaml: str


class PostApplyResourcesSectionVisibleItemValueMcnYamlDiffItemYamlDiff(BaseModel):
    diff: str

    left_description: str

    left_yaml: str

    right_description: str

    right_yaml: str


class PostApplyResourcesSectionVisibleItemValueMcnYamlDiffItem(BaseModel):
    item_type: str

    yaml_diff: PostApplyResourcesSectionVisibleItemValueMcnYamlDiffItemYamlDiff


class PostApplyResourcesSectionVisibleItemValueMcnResourcePreviewItemResourcePreview(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class PostApplyResourcesSectionVisibleItemValueMcnResourcePreviewItem(BaseModel):
    item_type: str

    resource_preview: PostApplyResourcesSectionVisibleItemValueMcnResourcePreviewItemResourcePreview


class PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnStringItem(BaseModel):
    item_type: str

    string: str


class PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnResourcePreviewItemResourcePreview(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnResourcePreviewItem(BaseModel):
    item_type: str

    resource_preview: PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnResourcePreviewItemResourcePreview


PostApplyResourcesSectionVisibleItemValueMcnListItemList: TypeAlias = Annotated[
    Union[
        PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnStringItem,
        PostApplyResourcesSectionVisibleItemValueMcnListItemListMcnResourcePreviewItem,
    ],
    PropertyInfo(discriminator="item_type"),
]


class PostApplyResourcesSectionVisibleItemValueMcnListItem(BaseModel):
    item_type: str

    rule_list: List[PostApplyResourcesSectionVisibleItemValueMcnListItemList] = FieldInfo(alias="list")


PostApplyResourcesSectionVisibleItemValue: TypeAlias = Annotated[
    Union[
        PostApplyResourcesSectionVisibleItemValueMcnStringItem,
        PostApplyResourcesSectionVisibleItemValueMcnYamlItem,
        PostApplyResourcesSectionVisibleItemValueMcnYamlDiffItem,
        PostApplyResourcesSectionVisibleItemValueMcnResourcePreviewItem,
        PostApplyResourcesSectionVisibleItemValueMcnListItem,
    ],
    PropertyInfo(discriminator="item_type"),
]


class PostApplyResourcesSectionVisibleItem(BaseModel):
    help_text: Optional[str] = FieldInfo(alias="helpText", default=None)

    name: Optional[str] = None

    value: Optional[PostApplyResourcesSectionVisibleItemValue] = None


class PostApplyResourcesSection(BaseModel):
    hidden_items: List[PostApplyResourcesSectionHiddenItem]

    name: str

    visible_items: List[PostApplyResourcesSectionVisibleItem]

    help_text: Optional[str] = None


class PostApplyResourcesManagedBy(BaseModel):
    id: str

    client_type: Literal["MAGIC_WAN_CLOUD_ONRAMP"]

    name: str


class PostApplyResources(BaseModel):
    id: str

    account_id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    config: Dict[str, object]

    deployment_provider: str

    managed: bool

    monthly_cost_estimate: PostApplyResourcesMonthlyCostEstimate

    name: str

    native_id: str

    observations: Dict[str, PostApplyResourcesObservations]

    provider_ids: List[str]

    provider_names_by_id: Dict[str, str]

    region: str

    resource_group: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    sections: List[PostApplyResourcesSection]

    state: Dict[str, object]

    tags: Dict[str, str]

    updated_at: str

    url: str

    managed_by: Optional[List[PostApplyResourcesManagedBy]] = None


class StatusApplyProgress(BaseModel):
    done: int

    total: int


class StatusPlanProgress(BaseModel):
    done: int

    total: int


class StatusLifecycleErrorsMeta(BaseModel):
    l10n_key: Optional[str] = None

    loggable_error: Optional[str] = None

    template_data: Optional[object] = None

    trace_id: Optional[str] = None


class StatusLifecycleErrorsSource(BaseModel):
    parameter: Optional[str] = None

    parameter_value_index: Optional[int] = None

    pointer: Optional[str] = None


class StatusLifecycleErrors(BaseModel):
    code: Literal[
        1001,
        1002,
        1003,
        1004,
        1005,
        1006,
        1007,
        1008,
        1009,
        1010,
        1011,
        1012,
        1013,
        1014,
        1015,
        1016,
        1017,
        1018,
        2001,
        2002,
        2003,
        2004,
        2005,
        2006,
        2007,
        2008,
        2009,
        2010,
        2011,
        2012,
        2013,
        2014,
        2015,
        2016,
        2017,
        2018,
        2019,
        2020,
        2021,
        2022,
        3001,
        3002,
        3003,
        3004,
        3005,
        3006,
        3007,
        4001,
        4002,
        4003,
        4004,
        4005,
        4006,
        4007,
        4008,
        4009,
        4010,
        4011,
        4012,
        4013,
        4014,
        4015,
        4016,
        4017,
        4018,
        4019,
        4020,
        4021,
        4022,
        4023,
        5001,
        5002,
        5003,
        5004,
        102000,
        102001,
        102002,
        102003,
        102004,
        102005,
        102006,
        102007,
        102008,
        102009,
        102010,
        102011,
        102012,
        102013,
        102014,
        102015,
        102016,
        102017,
        102018,
        102019,
        102020,
        102021,
        102022,
        102023,
        102024,
        102025,
        102026,
        102027,
        102028,
        102029,
        102030,
        102031,
        102032,
        102033,
        102034,
        102035,
        102036,
        102037,
        102038,
        102039,
        102040,
        102041,
        102042,
        102043,
        102044,
        102045,
        102046,
        102047,
        102048,
        102049,
        102050,
        102051,
        102052,
        102053,
        102054,
        102055,
        102056,
        102057,
        102058,
        102059,
        102060,
        102061,
        102062,
        102063,
        102064,
        102065,
        102066,
        102067,
        102068,
        102069,
        102070,
        102071,
        102072,
        103001,
        103002,
        103003,
        103004,
        103005,
        103006,
        103007,
        103008,
    ]

    message: str

    documentation_url: Optional[str] = None

    meta: Optional[StatusLifecycleErrorsMeta] = None

    source: Optional[StatusLifecycleErrorsSource] = None


class Status(BaseModel):
    apply_progress: StatusApplyProgress

    lifecycle_state: Literal[
        "OnrampNeedsApply",
        "OnrampPendingPlan",
        "OnrampPlanning",
        "OnrampPlanFailed",
        "OnrampPendingApproval",
        "OnrampPendingApply",
        "OnrampApplying",
        "OnrampApplyFailed",
        "OnrampActive",
        "OnrampPendingDestroy",
        "OnrampDestroying",
        "OnrampDestroyFailed",
    ]

    plan_progress: StatusPlanProgress

    routes: List[str]

    tunnels: List[str]

    lifecycle_errors: Optional[Dict[str, StatusLifecycleErrors]] = None


class VPCsByIDMonthlyCostEstimate(BaseModel):
    currency: str

    monthly_cost: float


class VPCsByIDObservations(BaseModel):
    first_observed_at: str

    last_observed_at: str

    provider_id: str

    resource_id: str


class VPCsByIDSectionHiddenItemValueMcnStringItem(BaseModel):
    item_type: str

    string: str


class VPCsByIDSectionHiddenItemValueMcnYamlItem(BaseModel):
    item_type: str

    yaml: str


class VPCsByIDSectionHiddenItemValueMcnYamlDiffItemYamlDiff(BaseModel):
    diff: str

    left_description: str

    left_yaml: str

    right_description: str

    right_yaml: str


class VPCsByIDSectionHiddenItemValueMcnYamlDiffItem(BaseModel):
    item_type: str

    yaml_diff: VPCsByIDSectionHiddenItemValueMcnYamlDiffItemYamlDiff


class VPCsByIDSectionHiddenItemValueMcnResourcePreviewItemResourcePreview(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class VPCsByIDSectionHiddenItemValueMcnResourcePreviewItem(BaseModel):
    item_type: str

    resource_preview: VPCsByIDSectionHiddenItemValueMcnResourcePreviewItemResourcePreview


class VPCsByIDSectionHiddenItemValueMcnListItemListMcnStringItem(BaseModel):
    item_type: str

    string: str


class VPCsByIDSectionHiddenItemValueMcnListItemListMcnResourcePreviewItemResourcePreview(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class VPCsByIDSectionHiddenItemValueMcnListItemListMcnResourcePreviewItem(BaseModel):
    item_type: str

    resource_preview: VPCsByIDSectionHiddenItemValueMcnListItemListMcnResourcePreviewItemResourcePreview


VPCsByIDSectionHiddenItemValueMcnListItemList: TypeAlias = Annotated[
    Union[
        VPCsByIDSectionHiddenItemValueMcnListItemListMcnStringItem,
        VPCsByIDSectionHiddenItemValueMcnListItemListMcnResourcePreviewItem,
    ],
    PropertyInfo(discriminator="item_type"),
]


class VPCsByIDSectionHiddenItemValueMcnListItem(BaseModel):
    item_type: str

    rule_list: List[VPCsByIDSectionHiddenItemValueMcnListItemList] = FieldInfo(alias="list")


VPCsByIDSectionHiddenItemValue: TypeAlias = Annotated[
    Union[
        VPCsByIDSectionHiddenItemValueMcnStringItem,
        VPCsByIDSectionHiddenItemValueMcnYamlItem,
        VPCsByIDSectionHiddenItemValueMcnYamlDiffItem,
        VPCsByIDSectionHiddenItemValueMcnResourcePreviewItem,
        VPCsByIDSectionHiddenItemValueMcnListItem,
    ],
    PropertyInfo(discriminator="item_type"),
]


class VPCsByIDSectionHiddenItem(BaseModel):
    help_text: Optional[str] = FieldInfo(alias="helpText", default=None)

    name: Optional[str] = None

    value: Optional[VPCsByIDSectionHiddenItemValue] = None


class VPCsByIDSectionVisibleItemValueMcnStringItem(BaseModel):
    item_type: str

    string: str


class VPCsByIDSectionVisibleItemValueMcnYamlItem(BaseModel):
    item_type: str

    yaml: str


class VPCsByIDSectionVisibleItemValueMcnYamlDiffItemYamlDiff(BaseModel):
    diff: str

    left_description: str

    left_yaml: str

    right_description: str

    right_yaml: str


class VPCsByIDSectionVisibleItemValueMcnYamlDiffItem(BaseModel):
    item_type: str

    yaml_diff: VPCsByIDSectionVisibleItemValueMcnYamlDiffItemYamlDiff


class VPCsByIDSectionVisibleItemValueMcnResourcePreviewItemResourcePreview(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class VPCsByIDSectionVisibleItemValueMcnResourcePreviewItem(BaseModel):
    item_type: str

    resource_preview: VPCsByIDSectionVisibleItemValueMcnResourcePreviewItemResourcePreview


class VPCsByIDSectionVisibleItemValueMcnListItemListMcnStringItem(BaseModel):
    item_type: str

    string: str


class VPCsByIDSectionVisibleItemValueMcnListItemListMcnResourcePreviewItemResourcePreview(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    detail: str

    name: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    title: str


class VPCsByIDSectionVisibleItemValueMcnListItemListMcnResourcePreviewItem(BaseModel):
    item_type: str

    resource_preview: VPCsByIDSectionVisibleItemValueMcnListItemListMcnResourcePreviewItemResourcePreview


VPCsByIDSectionVisibleItemValueMcnListItemList: TypeAlias = Annotated[
    Union[
        VPCsByIDSectionVisibleItemValueMcnListItemListMcnStringItem,
        VPCsByIDSectionVisibleItemValueMcnListItemListMcnResourcePreviewItem,
    ],
    PropertyInfo(discriminator="item_type"),
]


class VPCsByIDSectionVisibleItemValueMcnListItem(BaseModel):
    item_type: str

    rule_list: List[VPCsByIDSectionVisibleItemValueMcnListItemList] = FieldInfo(alias="list")


VPCsByIDSectionVisibleItemValue: TypeAlias = Annotated[
    Union[
        VPCsByIDSectionVisibleItemValueMcnStringItem,
        VPCsByIDSectionVisibleItemValueMcnYamlItem,
        VPCsByIDSectionVisibleItemValueMcnYamlDiffItem,
        VPCsByIDSectionVisibleItemValueMcnResourcePreviewItem,
        VPCsByIDSectionVisibleItemValueMcnListItem,
    ],
    PropertyInfo(discriminator="item_type"),
]


class VPCsByIDSectionVisibleItem(BaseModel):
    help_text: Optional[str] = FieldInfo(alias="helpText", default=None)

    name: Optional[str] = None

    value: Optional[VPCsByIDSectionVisibleItemValue] = None


class VPCsByIDSection(BaseModel):
    hidden_items: List[VPCsByIDSectionHiddenItem]

    name: str

    visible_items: List[VPCsByIDSectionVisibleItem]

    help_text: Optional[str] = None


class VPCsByIDManagedBy(BaseModel):
    id: str

    client_type: Literal["MAGIC_WAN_CLOUD_ONRAMP"]

    name: str


class VPCsByID(BaseModel):
    id: str

    account_id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE", "CLOUDFLARE"]

    config: Dict[str, object]

    deployment_provider: str

    managed: bool

    monthly_cost_estimate: VPCsByIDMonthlyCostEstimate

    name: str

    native_id: str

    observations: Dict[str, VPCsByIDObservations]

    provider_ids: List[str]

    provider_names_by_id: Dict[str, str]

    region: str

    resource_group: str

    resource_type: Literal[
        "aws_customer_gateway",
        "aws_egress_only_internet_gateway",
        "aws_internet_gateway",
        "aws_instance",
        "aws_network_interface",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_security_group",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpc_security_group_egress_rule",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_ec2_transit_gateway_vpc_attachment",
        "azurerm_application_security_group",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_rule",
        "azurerm_local_network_gateway",
        "azurerm_network_interface",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_security_group",
        "azurerm_public_ip",
        "azurerm_route",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_route_table_association",
        "azurerm_virtual_machine",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "google_compute_network",
        "google_compute_subnetwork",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_compute_route",
        "google_compute_address",
        "google_compute_global_address",
        "google_compute_router",
        "google_compute_interconnect_attachment",
        "google_compute_ha_vpn_gateway",
        "google_compute_forwarding_rule",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_rule",
        "cloudflare_static_route",
        "cloudflare_ipsec_tunnel",
    ]

    sections: List[VPCsByIDSection]

    state: Dict[str, object]

    tags: Dict[str, str]

    updated_at: str

    url: str

    managed_by: Optional[List[VPCsByIDManagedBy]] = None


class OnRampUpdateResponse(BaseModel):
    id: str

    cloud_type: Literal["AWS", "AZURE", "GOOGLE"]

    dynamic_routing: bool

    install_routes_in_cloud: bool

    install_routes_in_magic_wan: bool

    name: str

    type: Literal["OnrampTypeSingle", "OnrampTypeHub"]

    updated_at: str

    attached_hubs: Optional[List[str]] = None

    attached_vpcs: Optional[List[str]] = None

    cloud_asn: Optional[int] = None

    description: Optional[str] = None

    hub: Optional[str] = None

    last_applied_at: Optional[str] = None

    last_exported_at: Optional[str] = None

    last_planned_at: Optional[str] = None

    manage_hub_to_hub_attachments: Optional[bool] = None

    manage_vpc_to_hub_attachments: Optional[bool] = None

    planned_monthly_cost_estimate: Optional[PlannedMonthlyCostEstimate] = None

    planned_resources: Optional[List[PlannedResource]] = None

    planned_resources_unavailable: Optional[bool] = None

    post_apply_monthly_cost_estimate: Optional[PostApplyMonthlyCostEstimate] = None

    post_apply_resources: Optional[Dict[str, PostApplyResources]] = None

    post_apply_resources_unavailable: Optional[bool] = None

    region: Optional[str] = None

    status: Optional[Status] = None

    vpc: Optional[str] = None

    vpcs_by_id: Optional[Dict[str, VPCsByID]] = None

    vpcs_by_id_unavailable: Optional[List[str]] = None
    """The list of vpc IDs for which resource details failed to generate."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["V1ListParams"]


class V1ListParams(TypedDict, total=False):
    account_id: Required[str]
    """Account identifier tag."""

    creator: Optional[str]
    """Internal user ID set within the creator field.

    Setting to empty string "" will return images where creator field is not set
    """

    page: float
    """Page number of paginated results."""

    per_page: float
    """Number of items per page."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["LivestreamGetLivestreamAnalyticsCompleteParams"]


class LivestreamGetLivestreamAnalyticsCompleteParams(TypedDict, total=False):
    account_id: Required[str]
    """The account identifier tag."""

    end_time: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Specify the end time range in ISO format to access the livestream analytics."""

    start_time: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Specify the start time range in ISO format to access the livestream analytics."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .fields import (
    FieldsResource,
    AsyncFieldsResource,
    FieldsResourceWithRawResponse,
    AsyncFieldsResourceWithRawResponse,
    FieldsResourceWithStreamingResponse,
    AsyncFieldsResourceWithStreamingResponse,
)
from .received import (
    ReceivedResource,
    AsyncReceivedResource,
    ReceivedResourceWithRawResponse,
    AsyncReceivedResourceWithRawResponse,
    ReceivedResourceWithStreamingResponse,
    AsyncReceivedResourceWithStreamingResponse,
)

__all__ = [
    "FieldsResource",
    "AsyncFieldsResource",
    "FieldsResourceWithRawResponse",
    "AsyncFieldsResourceWithRawResponse",
    "FieldsResourceWithStreamingResponse",
    "AsyncFieldsResourceWithStreamingResponse",
    "ReceivedResource",
    "AsyncReceivedResource",
    "ReceivedResourceWithRawResponse",
    "AsyncReceivedResourceWithRawResponse",
    "ReceivedResourceWithStreamingResponse",
    "AsyncReceivedResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from ..._models import BaseModel
from .scripts.consumer_script import ConsumerScript

__all__ = [
    "Script",
    "NamedHandler",
    "Observability",
    "ObservabilityLogs",
    "ObservabilityTraces",
    "Placement",
    "PlacementUnionMember0",
    "PlacementUnionMember1",
    "PlacementUnionMember2",
    "PlacementUnionMember3",
    "PlacementUnionMember4",
    "PlacementUnionMember5",
    "PlacementUnionMember6",
    "PlacementUnionMember7",
    "PlacementUnionMember7Target",
    "PlacementUnionMember7TargetRegion",
    "PlacementUnionMember7TargetHostname",
    "PlacementUnionMember7TargetHost",
]


class NamedHandler(BaseModel):
    handlers: Optional[List[str]] = None
    """The names of handlers exported as part of the named export."""

    name: Optional[str] = None
    """The name of the export."""


class ObservabilityLogs(BaseModel):
    """Log settings for the Worker."""

    enabled: bool
    """Whether logs are enabled for the Worker."""

    invocation_logs: bool
    """
    Whether
    [invocation logs](https://developers.cloudflare.com/workers/observability/logs/workers-logs/#invocation-logs)
    are enabled for the Worker.
    """

    destinations: Optional[List[str]] = None
    """A list of destinations where logs will be exported to."""

    head_sampling_rate: Optional[float] = None
    """The sampling rate for logs. From 0 to 1 (1 = 100%, 0.1 = 10%). Default is 1."""

    persist: Optional[bool] = None
    """Whether log persistence is enabled for the Worker."""


class ObservabilityTraces(BaseModel):
    """Trace settings for the Worker."""

    destinations: Optional[List[str]] = None
    """A list of destinations where traces will be exported to."""

    enabled: Optional[bool] = None
    """Whether traces are enabled for the Worker."""

    head_sampling_rate: Optional[float] = None
    """The sampling rate for traces. From 0 to 1 (1 = 100%, 0.1 = 10%). Default is 1."""

    persist: Optional[bool] = None
    """Whether trace persistence is enabled for the Worker."""


class Observability(BaseModel):
    """Observability settings for the Worker."""

    enabled: bool
    """Whether observability is enabled for the Worker."""

    head_sampling_rate: Optional[float] = None
    """The sampling rate for incoming requests.

    From 0 to 1 (1 = 100%, 0.1 = 10%). Default is 1.
    """

    logs: Optional[ObservabilityLogs] = None
    """Log settings for the Worker."""

    traces: Optional[ObservabilityTraces] = None
    """Trace settings for the Worker."""


class PlacementUnionMember0(BaseModel):
    mode: Literal["smart"]
    """
    Enables
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    last_analyzed_at: Optional[datetime] = None
    """
    The last time the script was analyzed for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """


class PlacementUnionMember1(BaseModel):
    region: str
    """Cloud region for targeted placement in format 'provider:region'."""

    last_analyzed_at: Optional[datetime] = None
    """
    The last time the script was analyzed for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """


class PlacementUnionMember2(BaseModel):
    hostname: str
    """HTTP hostname for targeted placement."""

    last_analyzed_at: Optional[datetime] = None
    """
    The last time the script was analyzed for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """


class PlacementUnionMember3(BaseModel):
    host: str
    """TCP host and port for targeted placement."""

    last_analyzed_at: Optional[datetime] = None
    """
    The last time the script was analyzed for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """


class PlacementUnionMember4(BaseModel):
    mode: Literal["targeted"]
    """Targeted placement mode."""

    region: str
    """Cloud region for targeted placement in format 'provider:region'."""

    last_analyzed_at: Optional[datetime] = None
    """
    The last time the script was analyzed for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """


class PlacementUnionMember5(BaseModel):
    hostname: str
    """HTTP hostname for targeted placement."""

    mode: Literal["targeted"]
    """Targeted placement mode."""

    last_analyzed_at: Optional[datetime] = None
    """
    The last time the script was analyzed for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """


class PlacementUnionMember6(BaseModel):
    host: str
    """TCP host and port for targeted placement."""

    mode: Literal["targeted"]
    """Targeted placement mode."""

    last_analyzed_at: Optional[datetime] = None
    """
    The last time the script was analyzed for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """


class PlacementUnionMember7TargetRegion(BaseModel):
    region: str
    """Cloud region in format 'provider:region'."""


class PlacementUnionMember7TargetHostname(BaseModel):
    hostname: str
    """HTTP hostname for targeted placement."""


class PlacementUnionMember7TargetHost(BaseModel):
    host: str
    """TCP host:port for targeted placement."""


PlacementUnionMember7Target: TypeAlias = Union[
    PlacementUnionMember7TargetRegion, PlacementUnionMember7TargetHostname, PlacementUnionMember7TargetHost
]


class PlacementUnionMember7(BaseModel):
    mode: Literal["targeted"]
    """Targeted placement mode."""

    target: List[PlacementUnionMember7Target]
    """Array of placement targets (currently limited to single target)."""

    last_analyzed_at: Optional[datetime] = None
    """
    The last time the script was analyzed for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """


Placement: TypeAlias = Union[
    PlacementUnionMember0,
    PlacementUnionMember1,
    PlacementUnionMember2,
    PlacementUnionMember3,
    PlacementUnionMember4,
    PlacementUnionMember5,
    PlacementUnionMember6,
    PlacementUnionMember7,
]


class Script(BaseModel):
    id: Optional[str] = None
    """The name used to identify the script."""

    compatibility_date: Optional[str] = None
    """Date indicating targeted support in the Workers runtime.

    Backwards incompatible fixes to the runtime following this date will not affect
    this Worker.
    """

    compatibility_flags: Optional[List[str]] = None
    """Flags that enable or disable certain features in the Workers runtime.

    Used to enable upcoming features or opt in or out of specific changes not
    included in a `compatibility_date`.
    """

    created_on: Optional[datetime] = None
    """When the script was created."""

    etag: Optional[str] = None
    """Hashed script content, can be used in a If-None-Match header when updating."""

    handlers: Optional[List[str]] = None
    """The names of handlers exported as part of the default export."""

    has_assets: Optional[bool] = None
    """Whether a Worker contains assets."""

    has_modules: Optional[bool] = None
    """Whether a Worker contains modules."""

    last_deployed_from: Optional[str] = None
    """The client most recently used to deploy this Worker."""

    logpush: Optional[bool] = None
    """Whether Logpush is turned on for the Worker."""

    migration_tag: Optional[str] = None
    """
    The tag of the Durable Object migration that was most recently applied for this
    Worker.
    """

    modified_on: Optional[datetime] = None
    """When the script was last modified."""

    named_handlers: Optional[List[NamedHandler]] = None
    """
    Named exports, such as Durable Object class implementations and named
    entrypoints.
    """

    observability: Optional[Observability] = None
    """Observability settings for the Worker."""

    placement: Optional[Placement] = None
    """
    Configuration for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    Specify mode='smart' for Smart Placement, or one of region/hostname/host.
    """

    placement_mode: Optional[Literal["smart", "targeted"]] = None
    """
    Configuration for
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    Specify mode='smart' for Smart Placement, or one of region/hostname/host.
    """

    placement_status: Optional[Literal["SUCCESS", "UNSUPPORTED_APPLICATION", "INSUFFICIENT_INVOCATIONS"]] = None
    """
    Status of
    [Smart Placement](https://developers.cloudflare.com/workers/configuration/smart-placement).
    """

    tag: Optional[str] = None
    """The immutable ID of the script."""

    tags: Optional[List[str]] = None
    """Tags associated with the Worker."""

    tail_consumers: Optional[List[ConsumerScript]] = None
    """List of Workers that will consume logs from the attached Worker."""

    usage_model: Optional[Literal["standard", "bundled", "unbound"]] = None
    """Usage model for the Worker invocations."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel
from .origin_cloud_region import OriginCloudRegion

__all__ = ["OriginCloudRegionGetResponse"]


class OriginCloudRegionGetResponse(BaseModel):
    """Response result for a single origin cloud region mapping."""

    id: Literal["origin_public_cloud_region"]

    editable: bool
    """Whether the setting can be modified by the current user."""

    value: OriginCloudRegion
    """A single origin IP-to-cloud-region mapping."""

    modified_on: Optional[datetime] = None
    """Time the mapping was last modified."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from ...._models import BaseModel

__all__ = [
    "BulkGetResponse",
    "BulkGetResponseItem",
    "BulkGetResponseItemAdditionalInformation",
    "BulkGetResponseItemApplication",
    "BulkGetResponseItemContentCategory",
    "BulkGetResponseItemInheritedContentCategory",
    "BulkGetResponseItemInheritedRiskType",
    "BulkGetResponseItemRiskType",
]


class BulkGetResponseItemAdditionalInformation(BaseModel):
    """Additional information related to the host name."""

    suspected_malware_family: Optional[str] = None
    """Suspected DGA malware family."""


class BulkGetResponseItemApplication(BaseModel):
    """Application that the hostname belongs to."""

    id: Optional[int] = None

    name: Optional[str] = None


class BulkGetResponseItemContentCategory(BaseModel):
    """Current content categories."""

    id: Optional[int] = None

    name: Optional[str] = None

    super_category_id: Optional[int] = None


class BulkGetResponseItemInheritedContentCategory(BaseModel):
    id: Optional[int] = None

    name: Optional[str] = None

    super_category_id: Optional[int] = None


class BulkGetResponseItemInheritedRiskType(BaseModel):
    id: Optional[int] = None

    name: Optional[str] = None

    super_category_id: Optional[int] = None


class BulkGetResponseItemRiskType(BaseModel):
    id: Optional[int] = None

    name: Optional[str] = None

    super_category_id: Optional[int] = None


class BulkGetResponseItem(BaseModel):
    additional_information: Optional[BulkGetResponseItemAdditionalInformation] = None
    """Additional information related to the host name."""

    application: Optional[BulkGetResponseItemApplication] = None
    """Application that the hostname belongs to."""

    content_categories: Optional[List[BulkGetResponseItemContentCategory]] = None

    domain: Optional[str] = None

    inherited_content_categories: Optional[List[BulkGetResponseItemInheritedContentCategory]] = None

    inherited_from: Optional[str] = None
    """
    Domain from which `inherited_content_categories` and `inherited_risk_types` are
    inherited, if applicable.
    """

    inherited_risk_types: Optional[List[BulkGetResponseItemInheritedRiskType]] = None

    popularity_rank: Optional[int] = None
    """
    Global Cloudflare 100k ranking for the last 30 days, if available for the
    hostname. The top ranked domain is 1, the lowest ranked domain is 100,000.
    """

    risk_score: Optional[float] = None
    """
    Hostname risk score, which is a value between 0 (lowest risk) to 1 (highest
    risk).
    """

    risk_types: Optional[List[BulkGetResponseItemRiskType]] = None


BulkGetResponse: TypeAlias = List[BulkGetResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["SubdomainListResponse"]


class SubdomainListResponse(BaseModel):
    enabled: bool
    """Whether Email Sending is enabled on this subdomain."""

    name: str
    """The subdomain domain name."""

    tag: str
    """Sending subdomain identifier."""

    created: Optional[datetime] = None
    """The date and time the destination address has been created."""

    dkim_selector: Optional[str] = None
    """The DKIM selector used for email signing."""

    modified: Optional[datetime] = None
    """The date and time the destination address was last modified."""

    return_path_domain: Optional[str] = None
    """The return-path domain used for bounce handling."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .config_get_response import ConfigGetResponse as ConfigGetResponse
from .config_create_params import ConfigCreateParams as ConfigCreateParams
from .config_create_response import ConfigCreateResponse as ConfigCreateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .full import (
    FullResource,
    AsyncFullResource,
    FullResourceWithRawResponse,
    AsyncFullResourceWithRawResponse,
    FullResourceWithStreamingResponse,
    AsyncFullResourceWithStreamingResponse,
)
from .configs import (
    ConfigsResource,
    AsyncConfigsResource,
    ConfigsResourceWithRawResponse,
    AsyncConfigsResourceWithRawResponse,
    ConfigsResourceWithStreamingResponse,
    AsyncConfigsResourceWithStreamingResponse,
)

__all__ = [
    "FullResource",
    "AsyncFullResource",
    "FullResourceWithRawResponse",
    "AsyncFullResourceWithRawResponse",
    "FullResourceWithStreamingResponse",
    "AsyncFullResourceWithStreamingResponse",
    "ConfigsResource",
    "AsyncConfigsResource",
    "ConfigsResourceWithRawResponse",
    "AsyncConfigsResourceWithRawResponse",
    "ConfigsResourceWithStreamingResponse",
    "AsyncConfigsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .kind import Kind as Kind
from .phase import Phase as Phase
from .logging import Logging as Logging
from .log_rule import LogRule as LogRule
from .skip_rule import SkipRule as SkipRule
from .block_rule import BlockRule as BlockRule
from .route_rule import RouteRule as RouteRule
from .score_rule import ScoreRule as ScoreRule
from .execute_rule import ExecuteRule as ExecuteRule
from .rewrite_rule import RewriteRule as RewriteRule
from .logging_param import LoggingParam as LoggingParam
from .redirect_rule import RedirectRule as RedirectRule
from .log_rule_param import LogRuleParam as LogRuleParam
from .set_config_rule import SetConfigRule as SetConfigRule
from .skip_rule_param import SkipRuleParam as SkipRuleParam
from .block_rule_param import BlockRuleParam as BlockRuleParam
from .route_rule_param import RouteRuleParam as RouteRuleParam
from .rule_edit_params import RuleEditParams as RuleEditParams
from .score_rule_param import ScoreRuleParam as ScoreRuleParam
from .serve_error_rule import ServeErrorRule as ServeErrorRule
from .ddos_dynamic_rule import DDoSDynamicRule as DDoSDynamicRule
from .execute_rule_param import ExecuteRuleParam as ExecuteRuleParam
from .phase_get_response import PhaseGetResponse as PhaseGetResponse
from .rewrite_rule_param import RewriteRuleParam as RewriteRuleParam
from .rule_create_params import RuleCreateParams as RuleCreateParams
from .rule_edit_response import RuleEditResponse as RuleEditResponse
from .phase_update_params import PhaseUpdateParams as PhaseUpdateParams
from .redirect_rule_param import RedirectRuleParam as RedirectRuleParam
from .ruleset_list_params import RulesetListParams as RulesetListParams
from .rule_create_response import RuleCreateResponse as RuleCreateResponse
from .rule_delete_response import RuleDeleteResponse as RuleDeleteResponse
from .ruleset_get_response import RulesetGetResponse as RulesetGetResponse
from .version_get_response import VersionGetResponse as VersionGetResponse
from .log_custom_field_rule import LogCustomFieldRule as LogCustomFieldRule
from .phase_update_response import PhaseUpdateResponse as PhaseUpdateResponse
from .ruleset_create_params import RulesetCreateParams as RulesetCreateParams
from .ruleset_list_response import RulesetListResponse as RulesetListResponse
from .ruleset_update_params import RulesetUpdateParams as RulesetUpdateParams
from .set_config_rule_param import SetConfigRuleParam as SetConfigRuleParam
from .version_list_response import VersionListResponse as VersionListResponse
from .compress_response_rule import CompressResponseRule as CompressResponseRule
from .managed_challenge_rule import ManagedChallengeRule as ManagedChallengeRule
from .serve_error_rule_param import ServeErrorRuleParam as ServeErrorRuleParam
from .ddos_dynamic_rule_param import DDoSDynamicRuleParam as DDoSDynamicRuleParam
from .ruleset_create_response import RulesetCreateResponse as RulesetCreateResponse
from .ruleset_update_response import RulesetUpdateResponse as RulesetUpdateResponse
from .set_cache_settings_rule import SetCacheSettingsRule as SetCacheSettingsRule
from .force_connection_close_rule import ForceConnectionCloseRule as ForceConnectionCloseRule
from .log_custom_field_rule_param import LogCustomFieldRuleParam as LogCustomFieldRuleParam
from .compress_response_rule_param import CompressResponseRuleParam as CompressResponseRuleParam
from .managed_challenge_rule_param import ManagedChallengeRuleParam as ManagedChallengeRuleParam
from .set_cache_settings_rule_param import SetCacheSettingsRuleParam as SetCacheSettingsRuleParam
from .force_connection_close_rule_param import ForceConnectionCloseRuleParam as ForceConnectionCloseRuleParam



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal, Required, TypedDict

__all__ = ["DestinationUpdateParams", "Configuration"]


class DestinationUpdateParams(TypedDict, total=False):
    account_id: Required[str]

    configuration: Required[Configuration]

    enabled: Required[bool]


class Configuration(TypedDict, total=False):
    headers: Required[Dict[str, str]]

    type: Required[Literal["logpush"]]

    url: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .bots.bots import (
    BotsResource,
    AsyncBotsResource,
    BotsResourceWithRawResponse,
    AsyncBotsResourceWithRawResponse,
    BotsResourceWithStreamingResponse,
    AsyncBotsResourceWithStreamingResponse,
)
from ...._compat import cached_property
from .to_markdown import (
    ToMarkdownResource,
    AsyncToMarkdownResource,
    ToMarkdownResourceWithRawResponse,
    AsyncToMarkdownResourceWithRawResponse,
    ToMarkdownResourceWithStreamingResponse,
    AsyncToMarkdownResourceWithStreamingResponse,
)
from ...._resource import SyncAPIResource, AsyncAPIResource
from .timeseries_groups import (
    TimeseriesGroupsResource,
    AsyncTimeseriesGroupsResource,
    TimeseriesGroupsResourceWithRawResponse,
    AsyncTimeseriesGroupsResourceWithRawResponse,
    TimeseriesGroupsResourceWithStreamingResponse,
    AsyncTimeseriesGroupsResourceWithStreamingResponse,
)
from .inference.inference import (
    InferenceResource,
    AsyncInferenceResource,
    InferenceResourceWithRawResponse,
    AsyncInferenceResourceWithRawResponse,
    InferenceResourceWithStreamingResponse,
    AsyncInferenceResourceWithStreamingResponse,
)
from .markdown_for_agents import (
    MarkdownForAgentsResource,
    AsyncMarkdownForAgentsResource,
    MarkdownForAgentsResourceWithRawResponse,
    AsyncMarkdownForAgentsResourceWithRawResponse,
    MarkdownForAgentsResourceWithStreamingResponse,
    AsyncMarkdownForAgentsResourceWithStreamingResponse,
)

__all__ = ["AIResource", "AsyncAIResource"]


class AIResource(SyncAPIResource):
    @cached_property
    def to_markdown(self) -> ToMarkdownResource:
        return ToMarkdownResource(self._client)

    @cached_property
    def inference(self) -> InferenceResource:
        return InferenceResource(self._client)

    @cached_property
    def bots(self) -> BotsResource:
        return BotsResource(self._client)

    @cached_property
    def timeseries_groups(self) -> TimeseriesGroupsResource:
        return TimeseriesGroupsResource(self._client)

    @cached_property
    def markdown_for_agents(self) -> MarkdownForAgentsResource:
        return MarkdownForAgentsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AIResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AIResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AIResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AIResourceWithStreamingResponse(self)


class AsyncAIResource(AsyncAPIResource):
    @cached_property
    def to_markdown(self) -> AsyncToMarkdownResource:
        return AsyncToMarkdownResource(self._client)

    @cached_property
    def inference(self) -> AsyncInferenceResource:
        return AsyncInferenceResource(self._client)

    @cached_property
    def bots(self) -> AsyncBotsResource:
        return AsyncBotsResource(self._client)

    @cached_property
    def timeseries_groups(self) -> AsyncTimeseriesGroupsResource:
        return AsyncTimeseriesGroupsResource(self._client)

    @cached_property
    def markdown_for_agents(self) -> AsyncMarkdownForAgentsResource:
        return AsyncMarkdownForAgentsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAIResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAIResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAIResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncAIResourceWithStreamingResponse(self)


class AIResourceWithRawResponse:
    def __init__(self, ai: AIResource) -> None:
        self._ai = ai

    @cached_property
    def to_markdown(self) -> ToMarkdownResourceWithRawResponse:
        return ToMarkdownResourceWithRawResponse(self._ai.to_markdown)

    @cached_property
    def inference(self) -> InferenceResourceWithRawResponse:
        return InferenceResourceWithRawResponse(self._ai.inference)

    @cached_property
    def bots(self) -> BotsResourceWithRawResponse:
        return BotsResourceWithRawResponse(self._ai.bots)

    @cached_property
    def timeseries_groups(self) -> TimeseriesGroupsResourceWithRawResponse:
        return TimeseriesGroupsResourceWithRawResponse(self._ai.timeseries_groups)

    @cached_property
    def markdown_for_agents(self) -> MarkdownForAgentsResourceWithRawResponse:
        return MarkdownForAgentsResourceWithRawResponse(self._ai.markdown_for_agents)


class AsyncAIResourceWithRawResponse:
    def __init__(self, ai: AsyncAIResource) -> None:
        self._ai = ai

    @cached_property
    def to_markdown(self) -> AsyncToMarkdownResourceWithRawResponse:
        return AsyncToMarkdownResourceWithRawResponse(self._ai.to_markdown)

    @cached_property
    def inference(self) -> AsyncInferenceResourceWithRawResponse:
        return AsyncInferenceResourceWithRawResponse(self._ai.inference)

    @cached_property
    def bots(self) -> AsyncBotsResourceWithRawResponse:
        return AsyncBotsResourceWithRawResponse(self._ai.bots)

    @cached_property
    def timeseries_groups(self) -> AsyncTimeseriesGroupsResourceWithRawResponse:
        return AsyncTimeseriesGroupsResourceWithRawResponse(self._ai.timeseries_groups)

    @cached_property
    def markdown_for_agents(self) -> AsyncMarkdownForAgentsResourceWithRawResponse:
        return AsyncMarkdownForAgentsResourceWithRawResponse(self._ai.markdown_for_agents)


class AIResourceWithStreamingResponse:
    def __init__(self, ai: AIResource) -> None:
        self._ai = ai

    @cached_property
    def to_markdown(self) -> ToMarkdownResourceWithStreamingResponse:
        return ToMarkdownResourceWithStreamingResponse(self._ai.to_markdown)

    @cached_property
    def inference(self) -> InferenceResourceWithStreamingResponse:
        return InferenceResourceWithStreamingResponse(self._ai.inference)

    @cached_property
    def bots(self) -> BotsResourceWithStreamingResponse:
        return BotsResourceWithStreamingResponse(self._ai.bots)

    @cached_property
    def timeseries_groups(self) -> TimeseriesGroupsResourceWithStreamingResponse:
        return TimeseriesGroupsResourceWithStreamingResponse(self._ai.timeseries_groups)

    @cached_property
    def markdown_for_agents(self) -> MarkdownForAgentsResourceWithStreamingResponse:
        return MarkdownForAgentsResourceWithStreamingResponse(self._ai.markdown_for_agents)


class AsyncAIResourceWithStreamingResponse:
    def __init__(self, ai: AsyncAIResource) -> None:
        self._ai = ai

    @cached_property
    def to_markdown(self) -> AsyncToMarkdownResourceWithStreamingResponse:
        return AsyncToMarkdownResourceWithStreamingResponse(self._ai.to_markdown)

    @cached_property
    def inference(self) -> AsyncInferenceResourceWithStreamingResponse:
        return AsyncInferenceResourceWithStreamingResponse(self._ai.inference)

    @cached_property
    def bots(self) -> AsyncBotsResourceWithStreamingResponse:
        return AsyncBotsResourceWithStreamingResponse(self._ai.bots)

    @cached_property
    def timeseries_groups(self) -> AsyncTimeseriesGroupsResourceWithStreamingResponse:
        return AsyncTimeseriesGroupsResourceWithStreamingResponse(self._ai.timeseries_groups)

    @cached_property
    def markdown_for_agents(self) -> AsyncMarkdownForAgentsResourceWithStreamingResponse:
        return AsyncMarkdownForAgentsResourceWithStreamingResponse(self._ai.markdown_for_agents)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .apps import (
    AppsResource,
    AsyncAppsResource,
    AppsResourceWithRawResponse,
    AsyncAppsResourceWithRawResponse,
    AppsResourceWithStreamingResponse,
    AsyncAppsResourceWithStreamingResponse,
)
from .pcaps import (
    PCAPsResource,
    AsyncPCAPsResource,
    PCAPsResourceWithRawResponse,
    AsyncPCAPsResourceWithRawResponse,
    PCAPsResourceWithStreamingResponse,
    AsyncPCAPsResourceWithStreamingResponse,
)
from .sites import (
    SitesResource,
    AsyncSitesResource,
    SitesResourceWithRawResponse,
    AsyncSitesResourceWithRawResponse,
    SitesResourceWithStreamingResponse,
    AsyncSitesResourceWithStreamingResponse,
)
from .routes import (
    RoutesResource,
    AsyncRoutesResource,
    RoutesResourceWithRawResponse,
    AsyncRoutesResourceWithRawResponse,
    RoutesResourceWithStreamingResponse,
    AsyncRoutesResourceWithStreamingResponse,
)
from .connectors import (
    ConnectorsResource,
    AsyncConnectorsResource,
    ConnectorsResourceWithRawResponse,
    AsyncConnectorsResourceWithRawResponse,
    ConnectorsResourceWithStreamingResponse,
    AsyncConnectorsResourceWithStreamingResponse,
)
from .gre_tunnels import (
    GRETunnelsResource,
    AsyncGRETunnelsResource,
    GRETunnelsResourceWithRawResponse,
    AsyncGRETunnelsResourceWithRawResponse,
    GRETunnelsResourceWithStreamingResponse,
    AsyncGRETunnelsResourceWithStreamingResponse,
)
from .ipsec_tunnels import (
    IPSECTunnelsResource,
    AsyncIPSECTunnelsResource,
    IPSECTunnelsResourceWithRawResponse,
    AsyncIPSECTunnelsResourceWithRawResponse,
    IPSECTunnelsResourceWithStreamingResponse,
    AsyncIPSECTunnelsResourceWithStreamingResponse,
)
from .magic_transit import (
    MagicTransitResource,
    AsyncMagicTransitResource,
    MagicTransitResourceWithRawResponse,
    AsyncMagicTransitResourceWithRawResponse,
    MagicTransitResourceWithStreamingResponse,
    AsyncMagicTransitResourceWithStreamingResponse,
)
from .cf_interconnects import (
    CfInterconnectsResource,
    AsyncCfInterconnectsResource,
    CfInterconnectsResourceWithRawResponse,
    AsyncCfInterconnectsResourceWithRawResponse,
    CfInterconnectsResourceWithStreamingResponse,
    AsyncCfInterconnectsResourceWithStreamingResponse,
)

__all__ = [
    "AppsResource",
    "AsyncAppsResource",
    "AppsResourceWithRawResponse",
    "AsyncAppsResourceWithRawResponse",
    "AppsResourceWithStreamingResponse",
    "AsyncAppsResourceWithStreamingResponse",
    "CfInterconnectsResource",
    "AsyncCfInterconnectsResource",
    "CfInterconnectsResourceWithRawResponse",
    "AsyncCfInterconnectsResourceWithRawResponse",
    "CfInterconnectsResourceWithStreamingResponse",
    "AsyncCfInterconnectsResourceWithStreamingResponse",
    "GRETunnelsResource",
    "AsyncGRETunnelsResource",
    "GRETunnelsResourceWithRawResponse",
    "AsyncGRETunnelsResourceWithRawResponse",
    "GRETunnelsResourceWithStreamingResponse",
    "AsyncGRETunnelsResourceWithStreamingResponse",
    "IPSECTunnelsResource",
    "AsyncIPSECTunnelsResource",
    "IPSECTunnelsResourceWithRawResponse",
    "AsyncIPSECTunnelsResourceWithRawResponse",
    "IPSECTunnelsResourceWithStreamingResponse",
    "AsyncIPSECTunnelsResourceWithStreamingResponse",
    "RoutesResource",
    "AsyncRoutesResource",
    "RoutesResourceWithRawResponse",
    "AsyncRoutesResourceWithRawResponse",
    "RoutesResourceWithStreamingResponse",
    "AsyncRoutesResourceWithStreamingResponse",
    "SitesResource",
    "AsyncSitesResource",
    "SitesResourceWithRawResponse",
    "AsyncSitesResourceWithRawResponse",
    "SitesResourceWithStreamingResponse",
    "AsyncSitesResourceWithStreamingResponse",
    "ConnectorsResource",
    "AsyncConnectorsResource",
    "ConnectorsResourceWithRawResponse",
    "AsyncConnectorsResourceWithRawResponse",
    "ConnectorsResourceWithStreamingResponse",
    "AsyncConnectorsResourceWithStreamingResponse",
    "PCAPsResource",
    "AsyncPCAPsResource",
    "PCAPsResourceWithRawResponse",
    "AsyncPCAPsResourceWithRawResponse",
    "PCAPsResourceWithStreamingResponse",
    "AsyncPCAPsResourceWithStreamingResponse",
    "MagicTransitResource",
    "AsyncMagicTransitResource",
    "MagicTransitResourceWithRawResponse",
    "AsyncMagicTransitResourceWithRawResponse",
    "MagicTransitResourceWithStreamingResponse",
    "AsyncMagicTransitResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .custom import (
    CustomResource,
    AsyncCustomResource,
    CustomResourceWithRawResponse,
    AsyncCustomResourceWithRawResponse,
    CustomResourceWithStreamingResponse,
    AsyncCustomResourceWithStreamingResponse,
)
from .entries import (
    EntriesResource,
    AsyncEntriesResource,
    EntriesResourceWithRawResponse,
    AsyncEntriesResourceWithRawResponse,
    EntriesResourceWithStreamingResponse,
    AsyncEntriesResourceWithStreamingResponse,
)
from .predefined import (
    PredefinedResource,
    AsyncPredefinedResource,
    PredefinedResourceWithRawResponse,
    AsyncPredefinedResourceWithRawResponse,
    PredefinedResourceWithStreamingResponse,
    AsyncPredefinedResourceWithStreamingResponse,
)
from .integration import (
    IntegrationResource,
    AsyncIntegrationResource,
    IntegrationResourceWithRawResponse,
    AsyncIntegrationResourceWithRawResponse,
    IntegrationResourceWithStreamingResponse,
    AsyncIntegrationResourceWithStreamingResponse,
)

__all__ = [
    "CustomResource",
    "AsyncCustomResource",
    "CustomResourceWithRawResponse",
    "AsyncCustomResourceWithRawResponse",
    "CustomResourceWithStreamingResponse",
    "AsyncCustomResourceWithStreamingResponse",
    "PredefinedResource",
    "AsyncPredefinedResource",
    "PredefinedResourceWithRawResponse",
    "AsyncPredefinedResourceWithRawResponse",
    "PredefinedResourceWithStreamingResponse",
    "AsyncPredefinedResourceWithStreamingResponse",
    "IntegrationResource",
    "AsyncIntegrationResource",
    "IntegrationResourceWithRawResponse",
    "AsyncIntegrationResourceWithRawResponse",
    "IntegrationResourceWithStreamingResponse",
    "AsyncIntegrationResourceWithStreamingResponse",
    "EntriesResource",
    "AsyncEntriesResource",
    "EntriesResourceWithRawResponse",
    "AsyncEntriesResourceWithRawResponse",
    "EntriesResourceWithStreamingResponse",
    "AsyncEntriesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = [
    "RecordingStartRecordingsParams",
    "AudioConfig",
    "InteractiveConfig",
    "RealtimekitBucketConfig",
    "RtmpOutConfig",
    "StorageConfig",
    "VideoConfig",
    "VideoConfigWatermark",
    "VideoConfigWatermarkSize",
]


class RecordingStartRecordingsParams(TypedDict, total=False):
    account_id: Required[str]
    """The account identifier tag."""

    allow_multiple_recordings: bool
    """By default, a meeting allows only one recording to run at a time.

    Enabling the `allow_multiple_recordings` parameter to true allows you to
    initiate multiple recordings concurrently in the same meeting. This allows you
    to record separate videos of the same meeting with different configurations,
    such as portrait mode or landscape mode.
    """

    audio_config: AudioConfig
    """Object containing configuration regarding the audio that is being recorded."""

    file_name_prefix: str
    """Update the recording file name."""

    interactive_config: InteractiveConfig
    """
    Allows you to add timed metadata to your recordings, which are digital markers
    inserted into a video file to provide contextual information at specific points
    in the content range. The ID3 tags containing this information are available to
    clients on the playback timeline in HLS format. The output files are generated
    in a compressed .tar format.
    """

    max_seconds: int
    """
    Specifies the maximum duration for recording in seconds, ranging from a minimum
    of 60 seconds to a maximum of 24 hours.
    """

    meeting_id: str
    """ID of the meeting to record."""

    realtimekit_bucket_config: RealtimekitBucketConfig

    rtmp_out_config: RtmpOutConfig

    storage_config: Optional[StorageConfig]

    url: str
    """Pass a custom url to record arbitary screen"""

    video_config: VideoConfig


class AudioConfig(TypedDict, total=False):
    """Object containing configuration regarding the audio that is being recorded."""

    channel: Literal["mono", "stereo"]
    """Audio signal pathway within an audio file that carries a specific sound source."""

    codec: Literal["MP3", "AAC"]
    """Codec using which the recording will be encoded.

    If VP8/VP9 is selected for videoConfig, changing audioConfig is not allowed. In
    this case, the codec in the audioConfig is automatically set to vorbis.
    """

    export_file: bool
    """Controls whether to export audio file seperately"""


class InteractiveConfig(TypedDict, total=False):
    """
    Allows you to add timed metadata to your recordings, which are digital markers inserted into a video file to provide contextual information at specific points in the content range. The ID3 tags containing this information are available to clients on the playback timeline in HLS format. The output files are generated in a compressed .tar format.
    """

    type: Literal["ID3"]
    """The metadata is presented in the form of ID3 tags."""


class RealtimekitBucketConfig(TypedDict, total=False):
    enabled: Required[bool]
    """Controls whether recordings are uploaded to RealtimeKit's bucket.

    If set to false, `download_url`, `audio_download_url`, `download_url_expiry`
    won't be generated for a recording.
    """


class RtmpOutConfig(TypedDict, total=False):
    rtmp_url: str
    """RTMP URL to stream to"""


class StorageConfig(TypedDict, total=False):
    type: Required[Literal["aws", "azure", "digitalocean", "gcs", "sftp"]]
    """Type of storage media."""

    access_key: str
    """Access key of the storage medium.

    Access key is not required for the `gcs` storage media type.

    Note that this field is not readable by clients, only writeable.
    """

    auth_method: Literal["KEY", "PASSWORD"]
    """Authentication method used for "sftp" type storage medium"""

    bucket: str
    """Name of the storage medium's bucket."""

    host: str
    """SSH destination server host for SFTP type storage medium"""

    password: str
    """
    SSH destination server password for SFTP type storage medium when auth_method is
    "PASSWORD". If auth_method is "KEY", this specifies the password for the ssh
    private key.
    """

    path: str
    """Path relative to the bucket root at which the recording will be placed."""

    port: float
    """SSH destination server port for SFTP type storage medium"""

    private_key: str
    """
    Private key used to login to destination SSH server for SFTP type storage
    medium, when auth_method used is "KEY"
    """

    region: str
    """Region of the storage medium."""

    secret: str
    """Secret key of the storage medium.

    Similar to `access_key`, it is only writeable by clients, not readable.
    """

    username: str
    """SSH destination server username for SFTP type storage medium"""


class VideoConfigWatermarkSize(TypedDict, total=False):
    """Size of the watermark"""

    height: int
    """Height of the watermark in px"""

    width: int
    """Width of the watermark in px"""


class VideoConfigWatermark(TypedDict, total=False):
    """Watermark to be added to the recording"""

    position: Literal["left top", "right top", "left bottom", "right bottom"]
    """Position of the watermark"""

    size: VideoConfigWatermarkSize
    """Size of the watermark"""

    url: str
    """URL of the watermark image"""


class VideoConfig(TypedDict, total=False):
    codec: Literal["H264", "VP8"]
    """Codec using which the recording will be encoded."""

    export_file: bool
    """Controls whether to export video file seperately"""

    height: int
    """Height of the recording video in pixels"""

    watermark: VideoConfigWatermark
    """Watermark to be added to the recording"""

    width: int
    """Width of the recording video in pixels"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .saml_certificate_create_response import SAMLCertificateCreateResponse as SAMLCertificateCreateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .network_path import NetworkPath

__all__ = ["NetworkPathResponse"]


class NetworkPathResponse(BaseModel):
    id: str
    """API Resource UUID tag."""

    device_name: Optional[str] = FieldInfo(alias="deviceName", default=None)

    interval: Optional[str] = None
    """The interval at which the Traceroute synthetic application test is set to run."""

    kind: Optional[Literal["traceroute"]] = None

    name: Optional[str] = None

    network_path: Optional[NetworkPath] = FieldInfo(alias="networkPath", default=None)

    url: Optional[str] = None
    """The host of the Traceroute synthetic application test"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["CertificateEditParams"]


class CertificateEditParams(TypedDict, total=False):
    zone_id: Required[str]

    enabled: Required[bool]
    """
    The current status of the device policy certificate provisioning feature for
    WARP clients.
    """
